#!/bin/bash
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
. /etc/os-release
OS=$ID

ASTFILE="/etc/asterisk/ombutel/extensions__70-blfext.conf"
SOURCEFILE=""


showusage()
{
    echo ""
    echo "Import_hints allow you to create configuration file for Complete PBX 5 automatically with extensions on distants PBX in order to get BLFExt working"
    echo "To use it, you need to specify these arguments: "
    echo "import_hints.sh -s file"
    echo ""
    echo "  -s : file containing distants extensions, 1 by line"
    echo ""
    exit 1
}

initopts()
{
    while getopts "s:" arg $@
    do
        case "$arg" in
            s)
                SOURCEFILE=$OPTARG
                ;;
        esac
    done

    if [ -z $SOURCEFILE ]
    then
        showusage
    fi
}

backup()
{
    #backup of actual file if exists
    if [ ! -d $DIR/backup ]
    then
        echo "Creating backup directory"
        mkdir "$DIR/backup"
    fi
    if [ -e /etc/asterisk/ombutel/extensions__70-blfext.conf ]
    then
        BAKFILE="$DIR/backup/extensions__70-blfext.conf.bak_$(date +%F)"
        echo "Creating backup of $ASTFILE in $BAKFILE"
        rm -f "$BAKFILE"
        cp "$ASTFILE" "$BAKFILE"
    fi
}

buildfilecontent()
{
    CONTENT=";This file has been auto generated by import_hints of BLFExt.\n[extension-hints](+)\n"
    while IFS='' read -r line || [[ -n $line ]]
    do
        CONTENT="${CONTENT}exten => $line,hint,Custom:$line\n"
    done < "$SOURCEFILE"
}



# Verification des parametres
initopts $@

# Backup de l'ancienne config
backup

#Lecture du fichier source, une ligne par une ligne
CONTENT="";
buildfilecontent

#ecriture du fichier
echo -e "$CONTENT" > $ASTFILE

#Reload du dialplan
asterisk -rx "dialplan reload"

echo "Content generated with success."
exit 0